# UI/UX Feedback

**ID:** Feedback-20260222-132751
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-22 13:58:16

## Selected Elements



## Feedback

now let's work on design mockup, requirement gathering and feature breakdown actions in the work flow as an CR to the workflow requirement.
they should be just like Refine idea action, when clicks on it, should show the mockup, with target inputs, for example, refine idea is the idea file, you can learn for action what input required by study related SKILLs(each action has a related SKILL behinds it), then also show the instruction and extract instructions texbox and text area as well. and the logic to execute, update action status and show the delivery should also be the same, try to reuse as much as you can.

with this CR so you may need update following things
1. the frontend code for workflow
2. backend api for example code for workflow-manager
3. related Skills for workflow supports.

## Screenshot

![Screenshot](./page-screenshot.png)
